netapp_ontap.models.key_server_no_records API documentation
Description: Copyright &copy; 2026 NetApp Inc. All rights reserved …

# Module `netapp_ontap.models.key_server_no_records`

Copyright © 2026 NetApp Inc. All rights reserved.

This file has been automatically generated based on the ONTAP REST API documentation.

## Classes

`class KeyServerNoRecordsSchema (*, only: types.StrSequenceOrSet | None = None, exclude: types.StrSequenceOrSet = (), many: bool | None = None, context: dict | None = None, load_only: types.StrSequenceOrSet = (), dump_only: types.StrSequenceOrSet = (), partial: bool | types.StrSequenceOrSet | None = None, unknown: str | None = None)`

  The fields of the KeyServerNoRecords object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC
  - abc.ABC

  ### Class variables

  `connectivity: KeyServerStateArray GET`

    A container for holding an array of the key server connectivity state for each node.

  `links: SelfLink GET`

    The links field of the key_server_no_records.

  `password: str PATCH`

    Password credentials for connecting with the key server. This is not audited.

    Example: password

  `server: str GET POST`

    External key server for key management. If no port is provided, a default port of 5696 is used. Not valid in POST if `records` is provided.

    Example: bulkkeyserver.com:5698

  `timeout: Size GET PATCH`

    I/O timeout in seconds for communicating with the key server.

    Example: 60

  `username: str GET PATCH`

    KMIP username credentials for connecting with the key server.

    Example: username